% This note is for LLO AFWFS calculations.

% input Q with distance from TT0.
q_ifo = waist2q(1.26e-3, -1.55);
q_omc = waist2q(465e-6, 0);

% The OMC telescope as installed
R = [5 4];        % mirror ROC
L = [0 1.79];     % mirror positions
zLast = [0.278];  % Distance TT2->OMC

% The current mode matching:
eta_mmt = etaQ(q_omc, qMultiTelescopeZ(q_ifo, R, L, L(end)+zLast));


% lengths for AFWFS telescope.
% the lens Radius is 257.5mm,  which makes for an 
% effective focus of 0.57 m and hence a mirror ROC of 2*0.57.
Rlens = 2*0.57;
% distance to lens constrained by layout
dLens = sqrt((1175-1350)^2 + (1980-1930)^2) + ...
        (550 --230);
dLens = dLens/1000  % the distance to the lens (1.14 m)

% here are my guess for the QPD positions
wPos = 1.76;      % the WFS telescope waist position (calculated below)
dPos = 0.73;       % the distance between the QPDs
qAFWFS = qMultiTelescopeZ(q_omc, Rlens, dLens, z);

qpdPos = [-1 1]*dPos/2 + wPos;    % The QPD locations.
qpdW = interp1(z, q2waist(qAFWFS), qpdPos)
qpdG = interp1(z, q2guoy(qAFWFS),  qpdPos);

z = linspace(0, 3, 1000);
figure(1);
subplot(2,1,1);
plot(z, q2waist(qAFWFS), '-', ...
     qpdPos, qpdW, '*');
 title('LLO AFWFS telescope calculations');
 ylabel('Beam radius [m]');
 
subplot(2,1,2);
plot(z, q2guoy(qAFWFS), '-', ...
     qpdPos, qpdG, '*');
ylabel('Guoy phase [deg]');
 xlabel('Displacement from OMC [m]');
 
 dqpdG = abs(qpdG(2) - qpdG(1))
qpd1 = wPos - dLens  - dPos/2
qpd2 = qpd1+dPos

% Discussion:  From Zemax the distance from the OMC to the lens is 0.96 m.
% The waist of the AFWFS telescope is at 1.76 m,  and the QPDs need to be
% spaced by about 75 cm around this waist position.  The waists at the QPDs
% will be about 500 microns.   This puts QPD1 at 43 cm from the lens and
% QPD2 at 116 cm from the lens
